@@ -1,11 +1,12 @@
 import commands
 import os.path
-import glob
+import fnmatch
 import gtk
 import gobject
 import random
+import fnmatch
 
-VERSION = "0.5.1"
+VERSION = "0.5.2"
 IS_MAEMO = commands.getoutput("uname -m")[0:3] == "arm" # if cpu type is ARM, we are on maemo
 
 # general settings
@@ -61,6 +62,12 @@ class Playlist(gtk.ListStore):
     def __setitem__(self, k, v):
         gtk.ListStore.__getitem__(self, k)[0] = v
     
+    def index(self, v):
+        for i in xrange(len(self)):
+            if self[i] is v:
+                return i
+            
+    
 class Song(dict):
     def __init__(self, data):
         dict.__init__(self)
@@ -71,6 +78,7 @@ class Song(dict):
             self["title"] = data[1]
             self["artist"] = data[2]
             self["album"] = data[3]
+            self["playcount"] = data[4]
         else:
             self.uri = data
     
@@ -79,11 +87,11 @@ class Song(dict):
             return None
         
         dir = os.path.dirname(self.uri[7:])
-
-        files = glob.iglob(dir+"/*.jpg")
-
+        
         try:
-            return files.next()
-        except StopIteration:
+            img = fnmatch.filter(os.listdir(dir), "*.jpg")[0]
+        except IndexError:
             return None
+        
+        return os.path.join(dir, img)
 
