@@ -20,7 +20,7 @@ class Config(gconf.Client):
     def notify(self, k):
         gconf.Client.notify(self, self._base_path + k)
     
-    def has_key(self, k):
+    def __contains__(self, k):
         return self.get(self._base_path + k) is not None
     
     def __getitem__(self, k):
