@@ -99,7 +99,7 @@ class Controller:
         
     def _handle_rpc(self, interface, method, arguments, user_data):
         action = dict();
-        action["toggle"] = self._window._controls.on_toggle
+        action["toggle"] = self._player.toggle
         action["prev"] = self._player.previous
         action["next"] = self._player.next
         
@@ -112,13 +112,13 @@ class Controller:
         
         self._refresh_playlist()
     
-    def _set_new_playlist(self, *args):
-        self._config["pos"] = 0
-        
+    def _set_new_playlist(self, *args):        
         self._refresh_playlist()
-
+        
         if self._config["shuffle"]:
             self._player.playlist.shuffle(True)
+        
+        self._config["pos"] = 0
     
     def _refresh_playlist(self):
         playlist = self._library.get_tracks(self._config)
@@ -129,7 +129,7 @@ class Controller:
         played = player.get_time()
         
         # workaround for bugged meamo
-        if not song.has_key("duration"):
+        if not "duration" in song:
             return
         
         if (played < song["duration"]/2 and played < 240) or song["duration"] < 30:
@@ -149,13 +149,6 @@ class Controller:
                 self._scrobbler.now_playing(song["artist"], song["title"], song["album"])
             except urllib2.URLError, e:
                 sys.stderr.write("lastfm.now_playing: %s\n" % e)
-    
-    def _show_preferences(self, caller):
-        if self._preferences is None:
-            self._preferences = Preferences(self._window, self._config, self._scrobbler)
-            self._preferences.show_all()
-    
-        self._preferences.show()
 
     def _on_library_updated(self, caller, was_updated):
         gobject.idle_add(self._banner.destroy)
@@ -200,7 +193,7 @@ class Controller:
         gtk.main_quit()
 
 def check_config(config):
-    if not config.has_key("volume"):
+    if not "volume" in config:
         # write default config
         config["volume"] = 0.5
         config["search-str"] = ""
@@ -213,14 +206,14 @@ def check_config(config):
         config["no-rg-preamp"] = -10  # amp value to be used if no rg info is available (value: db)
     
     # order by was added in v0.3.5, therefore check for it seperately
-    if not config.has_key("order-by"):
+    if not "order-by" in config:
         config["order-by"] = "artist"
     
     # music-folder was added in v0.3.8
-    if not config.has_key("music-folder"):
+    if not "music-folder" in config:
         config["music-folder"] = "/home/user"
         
     # last.fm support was added in v0.4.0
-    if not config.has_key("lastfm-user"):
+    if not "lastfm-user" in config:
         config["lastfm-user"] = ""
         config["lastfm-pass"] = ""
\ No newline at end of file
