@@ -54,7 +54,7 @@ class Library(GObject):
     def get_tracks(self, config):        
         where_clause, variables = self._build_where_clause(config)
 
-        playlist = self._cursor.execute("""SELECT uri, title, artist, album
+        playlist = self._cursor.execute("""SELECT uri, title, artist, album, playcount
                                           FROM songs 
                                           %s
                                           ORDER BY %s""" % (where_clause, order[config["order-by"]]), \
