@@ -42,13 +42,17 @@ class Scrobbler():
         self._user = user
         self._pass = passwd
         self._client = client
+        self._state = None
         
         self._loginth = threading.Thread(target=self._login)
         self._loginth.start()
     
+    def get_state(self):
+        return self._state
+    
     def is_connected(self):
-        return self._session_id != None
-
+        return self._state == "OK"
+    
     def now_playing(self, artist, track, album="", length="", trackno="", mbid=""):
         """Tells audioscrobbler what is currently running in your player. This won't
            affect the user-profile on last.fm. To do submissions, use the "submit"
@@ -93,14 +97,18 @@ class Scrobbler():
        lines = result.split('\n')
        
        if lines[0] in ("BADAUTH", "BANNED", "BADTIME"):
-           raise ASError(lines[0])
+           self._state = lines[0]
+           return
+           #raise ASError(lines[0])
     
        elif lines[0].startswith('FAILED'):
           self._handle_hard_error()
-          raise ASError(lines[0])
+          self._state = lines[0]
+          #raise ASError(lines[0])
     
        elif lines[0] == 'OK':
           # wooooooohooooooo. We made it!
+          self._state = lines[0]
           self._session_id = lines[1]
           self._now_uri = lines[2]
           self._post_uri = lines[3]
