@@ -18,7 +18,8 @@ class Browser(gtk.TreeView):
         renderer = gtk.CellRendererText()
         renderer.set_property("ellipsize", pango.ELLIPSIZE_END)
         
-        self._state = NOTHING_SELECTED
+        self.selected = NOTHING_SELECTED
+        self._pos = {NOTHING_SELECTED: None, ARTIST_SELECTED: None}
         
         self._col = gtk.TreeViewColumn(None, renderer, text=0)
         self._col.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
@@ -28,28 +29,42 @@ class Browser(gtk.TreeView):
         self._library = library
 
         self.show_all()
-        
 
-    def show_albums(self, caller=None):        
+    def _restore_pos(self):
+        if self._pos[self.selected] is not None:
+            gobject.idle_add(self.set_cursor, self._pos[self.selected])
+
+    def show_albums(self, caller=None):
+        if not (self.selected & ALBUM_SELECTED):
+            self._config.notify("search-artist")
+              
         self._col.set_title(_("Albums"))
+        self.selected = ARTIST_SELECTED
         
         self._model.clear()
         self._model.append((_("All Albums"),))
         map(self._model.append, self._library.get_albums(self._config["search-artist"]))
+        self._restore_pos()
 
     def show_artists(self, caller=None):        
         self._col.set_title(_("Artist"))
-        
+        self.selected = NOTHING_SELECTED
+
         self._model.clear()
         self._model.append((_("All Artists"),))
         
         map(self._model.append, self._library.get_artists())
+        self._restore_pos()
+        
+        # reset pos for next step
+        self._pos[ARTIST_SELECTED] = None
         
     def _on_row_activated(self, caller, path, column):           
         selected = self._model[path][0] if path[0] > 0 else ""
-        
-        if not (self._state & ARTIST_SELECTED):
-            self._state |= ARTIST_SELECTED
+        self._pos[self.selected] = path[0]
+      
+        if not (self.selected & ARTIST_SELECTED):
+            self.selected |= ARTIST_SELECTED
                  
             self._config["search-artist"] = selected
             
@@ -57,8 +72,8 @@ class Browser(gtk.TreeView):
             self._config.notify("search-artist")
             
             self.show_albums()
-        elif not (self._state & ALBUM_SELECTED):
-            self._state |= ALBUM_SELECTED
+        elif not (self.selected & ALBUM_SELECTED):
+            self.selected |= ALBUM_SELECTED
             
             # FIXME force emit, since Mameo does not see changes otherwise
             self._config["search-album"] = selected
