@@ -9,7 +9,18 @@ class PrefLabel(gtk.Label):
         self.set_alignment(0, 0.5)
 
 class Preferences(gtk.Window):
-    def __init__(self, parent, config, scrobbler):
+    def __init__(self, *args):
+        self._created = False
+        self._args = args
+    
+    def cshow(self):
+        if not self._created:
+            self._create(*self._args)
+            self._created = True
+        
+        self.show()
+
+    def _create(self, parent, config, scrobbler):
         gtk.Window.__init__(self)
         self.config = config
         
@@ -112,6 +123,7 @@ class Preferences(gtk.Window):
         hbox.pack_end(close, expand=False)
         
         self.connect("delete-event", self.hide_on_delete)
+        self.show_all()
     
     def _on_lfm_user_changed(self, caller):
         self.config["lastfm-user"] = caller.get_text()
