@@ -5,7 +5,7 @@ import pango
 
 from youamp.ui.controls import Controls
 from youamp.ui.searchview import SearchView
-
+from youamp.ui.detailswindow import DetailsWindow
 from youamp import IS_MAEMO, img_path
 
 class Menu(gtk.Menu):
@@ -57,16 +57,17 @@ class Menu(gtk.Menu):
 class CoverImage(gtk.Image):
     def __init__(self):
         gtk.Image.__init__(self)
-        self.file = None
-        self.size = 0
-        self._pb = None
+        self.file = ""
     
-    def get_pb(self):
-        return self._pb
+    def set_generic(self):
+        name = "audio-x-generic" if not IS_MAEMO else "gnome-mime-audio-x-mp3"
+        pb = gtk.icon_theme_get_default().load_icon(name, self.size_request()[1], 0)
+        self.set_from_pixbuf(pb)
+        self.file = None
     
     def set_from_file(self, file):
-        self._pb = gtk.gdk.pixbuf_new_from_file_at_size(file, self.size, self.size)
-        self.set_from_pixbuf(self._pb)
+        pb = gtk.gdk.pixbuf_new_from_file_at_size(file, *self.size_request())
+        self.set_from_pixbuf(pb)
         self.file = file
 
 class Window(hildon.Window):
@@ -90,12 +91,18 @@ class Window(hildon.Window):
         vbox.pack_start(hbox, expand=False)
                 
         # Cover
+        evbox = gtk.EventBox()
         self._cover = CoverImage()
-        hbox.pack_start(self._cover, expand=False)
+        evbox.add(self._cover)
+        evbox.connect("button-press-event", self._display_details)
+        hbox.pack_start(evbox, expand=False)
         
         vbox1 = gtk.VBox()
         hbox.pack_start(vbox1)
         
+        # Details
+        self._details = DetailsWindow.get_instance()
+        
         # Label
         self._label = gtk.Label()
         self._label.set_alignment(0, 0)
@@ -111,8 +118,8 @@ class Window(hildon.Window):
         
         hbox.show_all()
         
-        self._cover.size = hbox.size_request()[1]
-        self._cover.set_from_file(img_path % "audio-x-generic.png")
+        csize = hbox.size_request()[1]
+        self._cover.set_size_request(csize, csize)
         
         # View
         self.view = SearchView(self._config, self._player, self._library)
@@ -124,7 +131,12 @@ class Window(hildon.Window):
         self._player.connect("song-changed", self._update_songinfo)
         
         self.show()
-    
+
+    def _display_details(self, *args):
+        song = self._player.playlist[self._config["pos"]]      
+        self._details.set_data(song)
+        self._details.cshow()
+   
     def set_menu(self, menu):
         hildon.Window.set_menu(self, menu)
         
@@ -154,15 +166,14 @@ class Window(hildon.Window):
         # image
         cover_file = newsong.cover_uri()
         
-        if cover_file is None:
-            cover_file = img_path % "audio-x-generic.png"
-        
         if cover_file == self._cover.file:
             return
-        
-        self._cover.set_from_file(cover_file)
+        elif cover_file is None:
+            self._cover.set_generic()
+        else:
+            self._cover.set_from_file(cover_file)
             
         if not IS_MAEMO:
-            self.set_icon_list(self._cover.get_pb())
+            self.set_icon_list(self._cover.get_pixbuf())
         
         
